# Service Fabric Client APIs

> see https://aka.ms/autorest

This is the AutoRest configuration file for ServiceFabricClient.


---
## Getting Started
To build the SDK for ServiceFabricClient, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the ServiceFabricClient API.

``` yaml
openapi-type: data-plane
tag: '6.3'
```

### Suppression

``` yaml
directive:
  - suppress: OperationIdNounVerb
    reason: The operation names follow the Service Fabric Client API operation names from the existing .NET SDK.
  - suppress: ListInOperationName
    reason: The operation names follow the Service Fabric Client API operation names from the existing .NET SDK.
  - suppress: GetInOperationName
    reason: The operation names follow the Service Fabric Client API operation names from the existing .NET SDK.
  - suppress: PutInOperationName
    reason: The operation names follow the Service Fabric Client API operation names from the existing .NET SDK.
  - suppress: HttpsSupportedScheme
    reason: Service Fabric clusters are owned by the users and they can be configured to have a secure or un-secure client connection endpoint.
  - suppress: LongRunningOperationsWithLongRunningExtension
    reason: Service Fabric platform has already established pattern for paged responses based on ContinuationToken parameter.
  - suppress: SecurityDefinitionsStructure
    reason: Service Fabric clusters support various security mechanism for the REST endpoint, this includes certificate, Kerberos, AD, AAD and others. The documentation for the REST API includes information on how to authenticate to the cluster endpoint secured with different mechanisms.
  - suppress: LROStatusCodesReturnTypeSchema
    reason: Service Fabric platform uses query based mechanism for some of the long running operations.
  - suppress: PostOperationIdContainsUrlVerb
    reason: The URL scheme for Service Fabric does not follow Azure Service rules. Service Fabric supports various functions on different entities that are modeled using POST.
  - suppress: APIVersionPattern
    reason: The URL scheme for Service Fabric does not follow Azure Service rules. Service Fabric supports various functions on different entities that are modeled using POST.
  - suppress: DefinitionsPropertiesNamesCamelCase
    reason: The property names for Service Fabric follow the naming scheme of existing property names in our client SDK and concepts.
  - suppress: GuidUsage
    reason: The IDs of the service partition in Service Fabric are GUIDs.
  - suppress: EnumInsteadOfBoolean
    reason:  The boolean properties are actually boolean value in the Service Fabric's application model.
  - suppress: OperationsAPIImplementation
    reason: Service Fabric client API is not an ARM based API and hence this rule is not applicable.
  - suppress: XmsExamplesRequired
    reason: There are a lot of APIs that does not have the example. While it is being worked upon disabling this to ensure that we catch and fix other violations

```

### Tag: 6.2

These settings apply only when `--tag=6.2` is specified on the command line.

``` yaml $(tag) == '6.2'
input-file:
- Microsoft.ServiceFabric/stable/6.2/servicefabric.json

```

### Tag: 6.3

These settings apply only when `--tag=6.3` is specified on the command line.

``` yaml $(tag) == '6.3'
input-file:
- Microsoft.ServiceFabric/stable/6.3/servicefabric.json

```

---
# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.servicefabric
  package-name: azure-servicefabric
  package-version: 6.3.0.0
  add-credentials: true
  clear-output-folder: true
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-servicefabric/azure/servicefabric
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-servicefabric
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  azure-arm: true
  fluent: true
  namespace: com.microsoft.azure.servicefabric
  license-header: MICROSOFT_MIT_NO_CODEGEN
  payload-flattening-threshold: 1
  output-folder: $(azure-libraries-for-java-folder)/azure-servicefabric
```
